@@ -52,8 +52,7 @@ def get_args():
         '-l', '--log-file',
         # Replace to hardcode your web server's log file
         default="/var/log/nginx/access.log",
-        help='Specify the (Nginx) log file.',
-        type=argparse.FileType('r'))
+        help='Specify the (Nginx) log file.')
     parser.add_argument(
         '-m', '--map',
         action='store_true',
@@ -82,20 +81,56 @@ def get_args():
 
 
 def tail(logfile):
-    ''' Tail logfile '''
+    '''
+    Continuously read logfile for new lines. This will also load the new
+    logfile in case the current logfile is rotated by logrotate. In other
+    words, its function is similar to `Tail -F`
+    '''
+
+    # Open the file
+    current_logfile = open(logfile, "r")
 
     # Seek the end of the file
-    logfile.seek(0, os.SEEK_END)
+    current_logfile.seek(0, os.SEEK_END)
 
-    # Start infinite loop
+    # Save the current inode of the logfile
+    current_inode = os.fstat(current_logfile.fileno()).st_ino
+
+    # Start first loop
     while True:
-        # Read last line of file
-        line = logfile.readline()        # sleep if file hasn't been updated
-        if not line:
-            time.sleep(0.1)
-            continue
 
-        yield line
+        # Start second loop, which we break if no new line
+        while True:
+
+            # Read line from current logfile
+            line = current_logfile.readline()
+
+            # If no new line, break
+            if not line:
+                break
+
+            # Else, yield new line
+            else:
+                yield line
+
+        try:
+            # Once broken out of the second loop, compare inode of potential
+            # new log file
+            if os.stat(logfile).st_ino != current_inode:
+
+                # If new inode, then continue with this new log file
+                new = open(logfile, "r")
+                current_logfile.close()
+                current_logfile = new
+                current_logfile.seek(0, os.SEEK_END)
+                current_inode = os.fstat(current_logfile.fileno()).st_ino
+                continue
+
+        except IOError:
+            pass
+
+        # Sleep for 1 second, and repeat cycle
+        time.sleep(1)
 
 
 def main():
